# Conveyor Belt

A command line interface for the CONVEYOR laboratory information management system (LIMS) by the [Sheffield Bioinformatics Core Facility](https://sbc.shef.ac.uk/) and [The University of Sheffield IT Services](https://www.sheffield.ac.uk/it-services/research).

## Links

* [conveyorbelt](https://pypi.org/project/conveyorbelt/) at [PyPI](https://pypi.org/)

# Installation

First create a virtual environment in which to install this package using a package manager such as `venv` or `conda`. Then install the package using pip using this command:

```bash
pip install conveyorbelt
```

# Usage

Run the following command to view the summary of available commands:

```bash
conveyorbelt --help
```

## Authentication

When promoted, enter your API access token.

Your access token is available at https://cog-uk.shef.ac.uk/user/token

# Development

Publishing instructions are contained in `setup.py`.